@@ -30,7 +30,7 @@ use Storable;
 use Time::HiRes qw();
 use YAML::Syck;
 
-use version; our $VERSION = qv('0.0.6');
+use version; our $VERSION = qv('0.0.7');
 
 use constant MAX_INT => ~0>>1; # anything better?
 use constant DEFAULT_PROTOCOL => 1;
@@ -61,7 +61,6 @@ Reader/mirrorer:
     my $rf = File::Rsync::Mirror::Recentfile->new
       (
        filenameroot => "RECENT",
-       ignore_link_stat_errors => 1,
        interval => q(6h),
        localroot => "/home/ftp/pub/PAUSE/authors",
        remote_dir => "",
@@ -265,8 +264,8 @@ Only relevant for slaves.
 
 If set to true, rsync errors are ignored that complain about link stat
 errors. These seem to happen only when there are files missing at the
-origin. In race conditions this can always happen, so it is
-recommended to set this value to true.
+origin. In race conditions this can always happen, so it defaults to
+true.
 
 =item is_slave
 
@@ -602,6 +601,7 @@ sub get_remote_recentfile_as_tempfile {
     }
     my $gaveup = 0;
     my $retried = 0;
+    local($ENV{LANG}) = "C";
     while (!$self->rsync->exec(
                                src => $src,
                                dst => $dst,
@@ -706,9 +706,11 @@ sub get_remotefile {
              $path,
             );
     }
+    local($ENV{LANG}) = "C";
+    my $remoteroot = $self->remoteroot or die "Alert: missing remoteroot. Cannot continue";
     while (!$self->rsync->exec(
                                src => join("/",
-                                           $self->remoteroot,
+                                           $remoteroot,
                                            $path),
                                dst => $dst,
                               )) {
@@ -1275,14 +1277,38 @@ sub _mirror_perform_delayed_ops {
             require Carp;
             Carp::cluck ( "Warning: Error while unlinking '$dst': $!" );
         }
-        delete $delayed->{unlink}{$dst};
+        if ($self->verbose) {
+            my $doing = "Del";
+            my $LFH = $self->_logfilehandle;
+            printf $LFH
+                (
+                 "%-4s %d (%s) %s DONE\n",
+                 $doing,
+                 time,
+                 $self->interval,
+                 $dst,
+                );
+            delete $delayed->{unlink}{$dst};
+        }
     }
     for my $dst (sort {length($b) <=> length($a)} keys %{$delayed->{rmdir}}) {
         unless (rmdir $dst) {
             require Carp;
             Carp::cluck ( "Warning: Error on rmdir '$dst': $!" );
         }
-        delete $delayed->{rmdir}{$dst};
+        if ($self->verbose) {
+            my $doing = "Del";
+            my $LFH = $self->_logfilehandle;
+            printf $LFH
+                (
+                 "%-4s %d (%s) %s DONE\n",
+                 $doing,
+                 time,
+                 $self->interval,
+                 $dst,
+                );
+            delete $delayed->{rmdir}{$dst};
+        }
     }
 }
 
@@ -1321,6 +1347,7 @@ sub mirror_path {
         $fh->unlink_on_destroy(1);
         my $gaveup = 0;
         my $retried = 0;
+        local($ENV{LANG}) = "C";
         while (!$self->rsync->exec
                (
                 src => join("/",
@@ -1330,7 +1357,7 @@ sub mirror_path {
                 'files-from' => $fh->filename,
                )) {
             my(@err) = $self->rsync->err;
-            if ($self->ignore_link_stat_errors && "@err" =~ m{^ rsync: \s link_stat }x ) {
+            if ($self->_my_ignore_link_stat_errors && "@err" =~ m{^ rsync: \s link_stat }x ) {
                 if ($self->verbose) {
                     my $LFH = $self->_logfilehandle;
                     print $LFH "Info: ignoring link_stat error '@err'";
@@ -1352,6 +1379,7 @@ sub mirror_path {
     } else {
         my $dst = $self->local_path($path);
         mkpath dirname $dst;
+        local($ENV{LANG}) = "C";
         while (!$self->rsync->exec
                (
                 src => join("/",
@@ -1361,7 +1389,7 @@ sub mirror_path {
                 dst => $dst,
                 )) {
             my(@err) = $self->rsync->err;
-            if ($self->ignore_link_stat_errors && "@err" =~ m{^ rsync: \s link_stat }x ) {
+            if ($self->_my_ignore_link_stat_errors && "@err" =~ m{^ rsync: \s link_stat }x ) {
                 if ($self->verbose) {
                     my $LFH = $self->_logfilehandle;
                     print $LFH "Info: ignoring link_stat error '@err'";
@@ -1375,6 +1403,13 @@ sub mirror_path {
     return 1;
 }
 
+sub _my_ignore_link_stat_errors {
+    my($self) = @_;
+    my $x = $self->ignore_link_stat_errors;
+    $x = 1 unless defined $x;
+    return $x;
+}
+
 sub _my_current_rfile {
     my($self) = @_;
     my $rfile;
@@ -1833,6 +1868,7 @@ sub _sparse_clone {
                   _use_tempfile
                   aggregator
                   filenameroot
+                  ignore_link_stat_errors
                   is_slave
                   max_files_per_connection
                   protocol
